#[non_exhaustive]pub enum LeapExtendError {
NotStrictlyAscending,
NonUnitIncrement,
BufferFull,
}Expand description
Error returned by RuntimeLeapSeconds::try_extend.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotStrictlyAscending
The new entry’s tai_nanos is not strictly greater than the last
existing entry — the table would become unsorted.
NonUnitIncrement
The new entry’s tai_minus_utc is not exactly one more than the last
existing entry — every leap second must increment the counter by 1.
BufferFull
The runtime buffer is full; no more entries can be appended.