pub trait IntoScale<Target: TimeScale>: Sized {
// Required method
fn into_scale(self) -> Result<Time<Target>, GnssTimeError>;
}Expand description
Fixed-offset conversion between time scales.
This trait is implemented for conversions where the relationship between time scales is constant and independent of leap seconds.
Required Methods
Sourcefn into_scale(self) -> Result<Time<Target>, GnssTimeError>
fn into_scale(self) -> Result<Time<Target>, GnssTimeError>
Converts the value into the target time scale.
Errors
Returns GnssTimeError::Overflow if the result cannot be represented
in the target scale.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.